#ifndef MATH_FACTORY_H
#define MATH_FACTORY_H

#ifdef __GNUG__
#pragma interface
#endif

#include "LString.h"
#include "math_atom.h"

class MathInset;
class latexkeys;

MathAtom createMathInset(string const &);

#endif
